==> libgnomedb-3.1.2.tar.gz: libgnomedb-3.1.2/libgnomedb/gnome-db-dsn-spec.h <==
/* GNOME DB library
 * Copyright (C) 2005 The GNOME Foundation
 *
 * AUTHORS:
 *      Vivien Malerba <malerba@gnome_db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GNOME_DB_DSN_SPEC_H__
#define __GNOME_DB_DSN_SPEC_H__

#include <gtk/gtkvbox.h>

G_BEGIN_DECLS

#define GNOME_DB_TYPE_DSN_SPEC            (gnome_db_dsn_spec_get_type())
#define GNOME_DB_DSN_SPEC(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_DB_TYPE_DSN_SPEC, GnomeDbDsnSpec))
#define GNOME_DB_DSN_SPEC_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GNOME_DB_TYPE_DSN_SPEC, GnomeDbDsnSpecClass))
#define GNOME_DB_IS_DSN_SPEC(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GNOME_DB_TYPE_DSN_SPEC))
#define GNOME_DB_IS_DSN_SPEC_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_DSN_SPEC))

typedef struct _GnomeDbDsnSpec        GnomeDbDsnSpec;
typedef struct _GnomeDbDsnSpecClass   GnomeDbDsnSpecClass;
typedef struct _GnomeDbDsnSpecPrivate GnomeDbDsnSpecPrivate;

struct _GnomeDbDsnSpec {
	GtkVBox                box;
	GnomeDbDsnSpecPrivate *priv;
};

struct _GnomeDbDsnSpecClass {
	GtkVBoxClass           parent_class;

	/* signals */
	void                (* changed) (GnomeDbDsnSpec *spec);
};

GType       gnome_db_dsn_spec_get_type     (void) G_GNUC_CONST;
GtkWidget  *gnome_db_dsn_spec_new          (const gchar *provider);

void        gnome_db_dsn_spec_set_provider (GnomeDbDsnSpec *spec, const gchar *provider);
gboolean    gnome_db_dsn_spec_is_valid     (GnomeDbDsnSpec *spec);
gchar      *gnome_db_dsn_spec_get_specs    (GnomeDbDsnSpec *spec);
void        gnome_db_dsn_spec_set_specs    (GnomeDbDsnSpec *spec, const gchar *specs_string);

G_END_DECLS

#endif

==> libgnomedb3_3.0.0.orig.tar.gz: libgnomedb-3.0.0/libgnomedb/gnome-db-dsn-spec.h <==
/* GNOME DB library
 * Copyright (C) 2005 The GNOME Foundation
 *
 * AUTHORS:
 *      Vivien Malerba <malerba@gnome_db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GNOME_DB_DSN_SPEC_H__
#define __GNOME_DB_DSN_SPEC_H__

#include <gtk/gtkvbox.h>

G_BEGIN_DECLS

#define GNOME_DB_TYPE_DSN_SPEC            (gnome_db_dsn_spec_get_type())
#define GNOME_DB_DSN_SPEC(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_DB_TYPE_DSN_SPEC, GnomeDbDsnSpec))
#define GNOME_DB_DSN_SPEC_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GNOME_DB_TYPE_DSN_SPEC, GnomeDbDsnSpecClass))
#define GNOME_DB_IS_DSN_SPEC(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GNOME_DB_TYPE_DSN_SPEC))
#define GNOME_DB_IS_DSN_SPEC_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_DSN_SPEC))

typedef struct _GnomeDbDsnSpec        GnomeDbDsnSpec;
typedef struct _GnomeDbDsnSpecClass   GnomeDbDsnSpecClass;
typedef struct _GnomeDbDsnSpecPrivate GnomeDbDsnSpecPrivate;

struct _GnomeDbDsnSpec {
	GtkVBox                box;
	GnomeDbDsnSpecPrivate *priv;
};

struct _GnomeDbDsnSpecClass {
	GtkVBoxClass           parent_class;

	/* signals */
	void                (* changed) (GnomeDbDsnSpec *spec);
};

GType       gnome_db_dsn_spec_get_type     (void);
GtkWidget  *gnome_db_dsn_spec_new          (const gchar *provider);

void        gnome_db_dsn_spec_set_provider (GnomeDbDsnSpec *spec, const gchar *provider);
gboolean    gnome_db_dsn_spec_is_valid     (GnomeDbDsnSpec *spec);
gchar      *gnome_db_dsn_spec_get_specs    (GnomeDbDsnSpec *spec);
void        gnome_db_dsn_spec_set_specs    (GnomeDbDsnSpec *spec, const gchar *specs_string);

G_END_DECLS

#endif
